@@ -33,7 +33,10 @@ class VariableList2D:
         self.add(arr)
 
     def add(self, arr: np.ndarray):
-        self.vals = np.vstack((self.vals, arr))
+        if self.vals.size == np.array([]):
+            self.vals = np.array([arr])
+        else:
+            self.vals = np.vstack((self.vals, arr))
 
     def __iadd__(self, other):
         """Adds other to the last value, then appends"""
